==> jc-1.4.0.tar.gz: soot/shimple/toolkits/scalar/ShimpleLocalUses.h <==
// public class soot.shimple.toolkits.scalar.ShimpleLocalUses

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 34fc188847341644 soot_shimple_toolkits_scalar_ShimpleLocalUses

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_toolkits_scalar_ShimpleLocalUses_H_
#define _JC_soot_shimple_toolkits_scalar_ShimpleLocalUses_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_shimple_ShimpleBody$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method$_init$c808cb4dc246b024(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_soot_shimple_ShimpleBody$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method$getUsesOf$fae2068fd0c33534(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method$getUsesOf$de01c1d1f6666f7b(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method_info$getUsesOf$fae2068fd0c33534;
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method_info$getUsesOf$de01c1d1f6666f7b;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods {
	struct _jc_object	*(*getUsesOf$fae2068fd0c33534)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *);
	struct _jc_object	*(*getUsesOf$de01c1d1f6666f7b)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods	soot_shimple_toolkits_scalar_ShimpleLocalUses;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs {
	struct _jc_object	*localToUses;
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs {
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs	soot_shimple_toolkits_scalar_ShimpleLocalUses;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs	soot_shimple_toolkits_scalar_ShimpleLocalUses;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object {
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_ShimpleLocalUses, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_ShimpleLocalUses_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/toolkits/scalar/ShimpleLocalUses.h <==
// public class soot.shimple.toolkits.scalar.ShimpleLocalUses

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34fc188847341644 soot_shimple_toolkits_scalar_ShimpleLocalUses

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_toolkits_scalar_ShimpleLocalUses_H_
#define _JC_soot_shimple_toolkits_scalar_ShimpleLocalUses_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Local$object;
struct _jc_soot_Unit$object;
struct _jc_soot_shimple_ShimpleBody$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object;

typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method$_init$c808cb4dc246b024(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_soot_shimple_ShimpleBody$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method$getUsesOf$fae2068fd0c33534(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method$getUsesOf$de01c1d1f6666f7b(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method_info$getUsesOf$fae2068fd0c33534;
extern _jc_method _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$method_info$getUsesOf$de01c1d1f6666f7b;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods {
	struct _jc_object	*(*getUsesOf$fae2068fd0c33534)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUsesOf$de01c1d1f6666f7b)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vmethods	soot_shimple_toolkits_scalar_ShimpleLocalUses;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs {
	struct _jc_object	*localToUses;
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs {
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_refs	soot_shimple_toolkits_scalar_ShimpleLocalUses;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$sub_nonrefs	soot_shimple_toolkits_scalar_ShimpleLocalUses;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$object {
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$vtype _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_ShimpleLocalUses, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_ShimpleLocalUses$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_ShimpleLocalUses_H_ */
